# Changelog

## [2.4.0](https://github.com/flipper/pygrocy2/tree/2.4.0) (2025-01-09)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v2.2.0...2.4.0)

**Merged pull requests:**

- fix: set default value None for optional fields so we do not get validation error when the field is missing [\#2](https://github.com/flipper/pygrocy2/pull/2) ([umglurf](https://github.com/umglurf))

## [v2.2.0](https://github.com/flipper/pygrocy2/tree/v2.2.0) (2024-12-23)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v2.1.0...v2.2.0)

## [v2.1.0](https://github.com/flipper/pygrocy2/tree/v2.1.0) (2024-04-23)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v2.0.0...v2.1.0)

## [v2.0.0](https://github.com/flipper/pygrocy2/tree/v2.0.0) (2023-08-17)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v1.5.0...v2.0.0)

## [v1.5.0](https://github.com/flipper/pygrocy2/tree/v1.5.0) (2022-09-19)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v1.4.1...v1.5.0)

## [v1.4.1](https://github.com/flipper/pygrocy2/tree/v1.4.1) (2022-07-28)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v1.4.0...v1.4.1)

## [v1.4.0](https://github.com/flipper/pygrocy2/tree/v1.4.0) (2022-07-24)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v1.3.0...v1.4.0)

## [v1.3.0](https://github.com/flipper/pygrocy2/tree/v1.3.0) (2022-06-05)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v1.2.1...v1.3.0)

## [v1.2.1](https://github.com/flipper/pygrocy2/tree/v1.2.1) (2022-05-21)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v1.2.0...v1.2.1)

## [v1.2.0](https://github.com/flipper/pygrocy2/tree/v1.2.0) (2022-05-16)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v1.1.0...v1.2.0)

## [v1.1.0](https://github.com/flipper/pygrocy2/tree/v1.1.0) (2022-03-05)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v1.0.0...v1.1.0)

## [v1.0.0](https://github.com/flipper/pygrocy2/tree/v1.0.0) (2021-09-10)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.30.0...v1.0.0)

## [v0.30.0](https://github.com/flipper/pygrocy2/tree/v0.30.0) (2021-08-23)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.29.0...v0.30.0)

## [v0.29.0](https://github.com/flipper/pygrocy2/tree/v0.29.0) (2021-03-03)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.28.0...v0.29.0)

## [v0.28.0](https://github.com/flipper/pygrocy2/tree/v0.28.0) (2021-02-20)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.27.0...v0.28.0)

## [v0.27.0](https://github.com/flipper/pygrocy2/tree/v0.27.0) (2021-02-15)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.26.0...v0.27.0)

## [v0.26.0](https://github.com/flipper/pygrocy2/tree/v0.26.0) (2021-02-13)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.25.0...v0.26.0)

## [v0.25.0](https://github.com/flipper/pygrocy2/tree/v0.25.0) (2021-02-10)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.24.1...v0.25.0)

## [v0.24.1](https://github.com/flipper/pygrocy2/tree/v0.24.1) (2020-11-16)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.24.0...v0.24.1)

## [v0.24.0](https://github.com/flipper/pygrocy2/tree/v0.24.0) (2020-11-16)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.23.0...v0.24.0)

## [v0.23.0](https://github.com/flipper/pygrocy2/tree/v0.23.0) (2020-09-11)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.22.0...v0.23.0)

## [v0.22.0](https://github.com/flipper/pygrocy2/tree/v0.22.0) (2020-09-07)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.21.0...v0.22.0)

## [v0.21.0](https://github.com/flipper/pygrocy2/tree/v0.21.0) (2020-08-18)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.20.0...v0.21.0)

## [v0.20.0](https://github.com/flipper/pygrocy2/tree/v0.20.0) (2020-08-16)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.19.0...v0.20.0)

## [v0.19.0](https://github.com/flipper/pygrocy2/tree/v0.19.0) (2020-08-14)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.18.0...v0.19.0)

## [v0.18.0](https://github.com/flipper/pygrocy2/tree/v0.18.0) (2020-08-14)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.17.0...v0.18.0)

## [v0.17.0](https://github.com/flipper/pygrocy2/tree/v0.17.0) (2020-08-14)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.16.0...v0.17.0)

## [v0.16.0](https://github.com/flipper/pygrocy2/tree/v0.16.0) (2020-08-13)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.15.0...v0.16.0)

## [v0.15.0](https://github.com/flipper/pygrocy2/tree/v0.15.0) (2020-05-25)

[Full Changelog](https://github.com/flipper/pygrocy2/compare/v0.14.0...v0.15.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
